﻿//
// Parago Media GmbH & Co. KG, Jürgen Bäurle (jbaurle@parago.de)
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
// TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using WebSupergoo.ABCpdf8;

namespace SP2010HTML2PDF.ApplicationPages
{
	public partial class CreatePDFPage : LayoutsPageBase
	{
		protected void Page_Load(object sender, EventArgs e)
		{
			// NOTE: Acrobat Reader X stops displaying PDF in browser with the message "There is a problem with Adobe Acrobat/Reader. If it is running, 
			// please exit and try again. (103:103)". Uncheck the option for "Enable Protected Mode at startup" in the Reader X settings (Edit -> 
			// Preferences -> General)!
			// http://www.brain-cluster.com/blog/orange/2011/03/06/there-problem-adobe-acrobatreader-if-it-running-please-exit-and-try-again

			Guid listId;

			try
			{
				listId = new Guid(Request.QueryString["ListId"]);
			}
			catch
			{
				MessageLabel.Text = "QueryString parameter 'ListId' is not defined or not valid.";
				return;
			}

			if(!XSettings.LicenseValid)
			{
				MessageLabel.Text = "The current ABCpdf8 (trail) license is expired or not valid.";
				return;
			}

			try
			{
				string template = @"
<p>
All tasks for task list with name '{{SP.List.Title}}' and ID '{{SP.List.ID}}':
<ul>
{% for task in SP.Tasks %}
<li>{{task.Title}} (<i>(Start Date: {{task.Start_Date}})</i></li>
{% endfor %}
</ul>
</p>
";

				byte[] data = CreatePDF(CreateHTML(listId, template));

				Response.Clear();
				Response.ContentType = "application/pdf";
				Response.AddHeader("content-disposition", "inline; filename=Tasks.pdf");
				Response.AddHeader("content-length", data.Length.ToString());
				Response.BinaryWrite(data);
				Response.End();
			}
			catch(Exception ex)
			{
				MessageLabel.Text = "An error occurred during the creation of the PDF file.<br><br>Exception:<br><br>" + ex.Message;
			}
		}

		string CreateHTML(Guid listId, string template)
		{
			SPList list = Web.Lists[listId];

			TemplateManager tm = new TemplateManager();

			Dictionary<string, object> values = new Dictionary<string, object>();
			values.Add("List", list);
			values.Add("Tasks", list.GetItems());
			
			return tm.Render(template, values);
		}

		byte[] CreatePDF(string html)
		{
			Doc document = new Doc();

			document.MediaBox.String = "A4";
			document.Rect.String = document.MediaBox.String;

			document.Page = document.AddPage();
			int id = document.AddHtml(html);

			while(document.Chainable(id))
			{
				document.Page = document.AddPage();
				id = document.AddHtml(string.Empty, id);
			}

			return document.GetData();
		}
	}
}
