﻿//
// Parago Media GmbH & Co. KG, Jürgen Bäurle (jbaurle@parago.de)
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
// TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections;
using System.Collections.Generic;
using Microsoft.SharePoint;

namespace SP2010HTML2PDF
{
	internal static class DropHelper
	{
		public static object MayConvertToDrop(object value)
		{
			if(value != null)
			{
				// TODO: Add your own drop implementations here

				if(value is SPList)
					return new SPPropertyDrop(value);
				if(value is SPListCollection)
					return ConvertDropableList<SPPropertyDrop, SPList>(value as ICollection);
				if(value is SPListItem)
					return new SPListItemDrop(value as SPListItem);
				if(value is SPListItemCollection)
					return ConvertDropableList<SPListItemDrop, SPListItem>(value as ICollection);
				if(value is SPWeb)
					return new SPPropertyDrop(value);
				if(value is SPSite)
					return new SPPropertyDrop(value);
				if(value is SPUser)
					return new SPPropertyDrop(value);
				if(value is Uri)
					return ((Uri)value).ToString();
				if(value is Guid)
					return ((Guid)value).ToString("B");
			}

			return value;
		}

		public static List<TDrop> ConvertDropableList<TDrop, TItem>(ICollection collection) where TDrop : SPDropBase, new()
		{
			List<TDrop> list = new List<TDrop>();

			foreach(TItem item in collection)
			{
				if(item != null && item.GetType() == typeof(TItem))
				{
					SPDropBase drop = new TDrop();
					drop.DropableObject = item;
					list.Add((TDrop)drop);
				}
			}

			return list;
		}
	}
}
