﻿//
// Parago Media GmbH & Co. KG, Jürgen Bäurle (jbaurle@parago.de)
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
// TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using DotLiquid;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Utilities;

namespace SP2010HTML2PDF
{
	internal class SharePointDrop : Drop
	{
		Dictionary<string, object> _values;

		public SharePointDrop()
		{
			_values = new Dictionary<string, object>();

			if(SPContext.Current != null)
				_values.Add("Site", SPContext.Current.Site);
			if(SPContext.Current != null)
				_values.Add("Web", SPContext.Current.Web);
			if(SPContext.Current != null)
				_values.Add("User", SPContext.Current.Web.CurrentUser);

			_values.Add("Date", DateTime.Now);
			_values.Add("DateISO8601", SPUtility.CreateISO8601DateTimeFromSystemDateTime(DateTime.Now));

			// TODO: Add more default values
		}

		public void AddValue(string name, object value)
		{
			if(string.IsNullOrEmpty(name))
				throw new ArgumentNullException("name");

			if(_values.ContainsKey(name))
				_values[name] = value;
			else
				_values.Add(name, value);
		}

		public override object BeforeMethod(string method)
		{
			if(!string.IsNullOrEmpty(method) && _values.ContainsKey(method))
				return DropHelper.MayConvertToDrop(_values[method]);

			return null;
		}
	}
}
